<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
//use Illuminate\Support\Facades\Request;
use DB;
use App\Http\Controllers\SharedController;

class SiteMapController extends Controller
{
    private $route = "https://toulouseweb.com";
    private $default = array(
        "https://toulouseweb.com/",
        "https://toulouseweb.com/annuaire",
        "https://toulouseweb.com/agenda",
        "https://toulouseweb.com/annonces",
        "https://toulouseweb.com/bons_plans",
        "https://toulouseweb.com/rencontres",
        "https://toulouseweb.com/contact/societe",
        "https://toulouseweb.com/cinema",

        "https://toulouseweb.com/contact/publicite",
        "https://toulouseweb.com/contact/sites",
        "https://toulouseweb.com/recommander",

        "https://toulouseweb.com/agenda_add",
        "https://toulouseweb.com/area_add",
        "https://toulouseweb.com/new-news",
        "https://toulouseweb.com/toulousain_add",
        
        
    );

    protected $SharedController;

    public function __construct(SharedController $SharedController)
    {
        $this->SharedController = $SharedController;
    }


    public function generate(){
        return $this->script();
    }

    private function script(){
        $xml = new \SimpleXMLElement('<urlset/>');
        $urlset = $xml;
        $urlset->addAttribute("xmlns", "http://www.sitemaps.org/schemas/sitemap/0.9");
        $urlset->addAttribute("xmlns:news", "http://www.google.com/schemas/sitemap-news/0.9");
        $urlset->addAttribute("xmlns:xhtml", "http://www.w3.org/1999/xhtml");
        $urlset->addAttribute("xmlns:mobile", "http://www.google.com/schemas/sitemap-mobile/1.0");
        $urlset->addAttribute("xmlns:image", "http://www.google.com/schemas/sitemap-image/1.1l");
        $urlset->addAttribute("xmlns:video", "http://www.google.com/schemas/sitemap-video/1.1");

        foreach ($this->default as $index => $d) {
            $url = $xml->addChild('url');
            $loc = $url->addChild('loc',$d);
            if ($index <= 7) $url->addChild('priority','1.0');
            else if ($index > 7 && $index <=10) $url->addChild('priority','0.85');
            else $url->addChild('priority','0.8');
        }

        $agendas = DB::table('t_agenda_categories')->select('libelle')->where('status',1)->get();

        foreach ($agendas as $a) {
            if(!isset($a->libelle))
                continue;
            $url = $xml->addChild('url');
            $loc = $url->addChild('loc', $this->route.'/agenda/'.$a->libelle);
            $url->addChild('priority','0.75');
        }

        //detail-news?id=16225&comment=0&nom=LYGIE
        $news = DB::table('t_news')->select('titre','id', 'slug')->where('is_enabled', '=', 'T')->get();

        foreach ($news as $a) {
            $url = $xml->addChild('url');
            $lien = $this->route.'/news/'. $a->slug;
            $loc = $url->addChild('loc', htmlspecialchars($lien));
            $url->addChild('priority','0.75');
        }

        //annuaire?categorie=1&cat=a%2Bemporter
        //annuaire?categorie=1&n1=0&sousCategorie=332&cat=a%2Bemporter&scat=burger
        //$categories = DB::table('t_category')->select('nom','id','id_parent')->orderBy(DB::raw('id,id_parent'),'ASC')->get();

        $sql = "select 
                    c.nom, c.id, c.id_parent, c2.slug as 'parentSlug', c.slug as 'slug'
                from t_category c
                left join t_category c2 on c.id_parent = c2.id
                where c.statut = 1
                order by c.id, c.id_parent";
        $categories = DB::select( DB::raw($sql) );

        foreach ($categories as $a) {
            $url = $xml->addChild('url');
            if(!isset($a->id_parent)){                
                $loc = $url->addChild('loc', htmlspecialchars($this->route.'/annuaire/'.$a->slug));  
                $url->addChild('priority','0.75');
            }else{
                $loc = $url->addChild('loc', htmlspecialchars($this->route.'/annuaire/'.$a->parentSlug.'/'.$a->slug));  
                $url->addChild('priority','0.65');
            }
                      
        } 

        $sql = "select 
                    id, titre, slug
                from t_article a
                where a.statut = 1
                group by titre";
        $encadrer = DB::select( DB::raw($sql) );

        foreach ($encadrer as $a) {
            $url = $xml->addChild('url');
            $loc = $url->addChild('loc', htmlspecialchars($this->route.'/fiche/' . $a->slug));  
            $url->addChild('priority','0.75');       
        }

        $sql = "select 
                    id, nom, slug
                from t_cine c
                group by nom";
        $encadrer = DB::select( DB::raw($sql) );

        foreach ($encadrer as $a) {
            $url = $xml->addChild('url');
            $loc = $url->addChild('loc', htmlspecialchars($this->route.'/cinema/salle/' . $a->slug));  
            $url->addChild('priority','0.8');       
        }

        $sql = "select 
                    id, titre, slug
                from t_cine_film c
                group by titre";
        $encadrer = DB::select( DB::raw($sql) );

        foreach ($encadrer as $a) {
            $url = $xml->addChild('url');
            $loc = $url->addChild('loc', htmlspecialchars($this->route.'/film/' . $a->slug));  
            $url->addChild('priority','0.75');       
        }

        

        Header('Content-type: text/xml');

        return $xml->asXML();
    }

    private function format_params($urlString){
        $slug = htmlspecialchars($urlString);
        //$slug=preg_replace('/[^A-Za-z0-9-]+/', '-', $slug);
        return $slug;
    }

}
